@@ -16,6 +16,8 @@ G_BEGIN_DECLS
 #undef GDK_WINDOWING_WAYLAND
 #undef GDK_WINDOWING_WIN32
 
+#define GDK_RENDERING_CAIRO
+#define GDK_RENDERING_GL
 #undef GDK_RENDERING_VULKAN
 
 G_END_DECLS
